@@ -1,3 +1,3 @@
 from PyML.main import Document, HtmlNode, TextNode
 from PyML.utils import Table
-from PyML.window import Window, parse_soup_into_tag
+from PyML.window import Window
